pub fn apply_newline_behavior(text: &str, behavior: NewlineBehavior) -> StringExpand description
Applies a newline behavior to text and returns an owned string.
pub fn apply_newline_behavior(text: &str, behavior: NewlineBehavior) -> StringApplies a newline behavior to text and returns an owned string.